<?php
// Database connection and sessions.
require_once 'templates/config.php'
?>
<!DOCTYPE html>
<html>
<head>
    <title>SMVITM Student Grievance System</title>
    <!--Import Google Icon Font-->
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <!-- Compiled and minified CSS -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/materialize/1.0.0-rc.2/css/materialize.min.css">
    <!--Let browser know website is optimized for mobile-->
    <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
    <link rel="stylesheet" href="css/styles.css">
</head>
<body>

<?php include 'templates/navbar.php'; ?>

<?php
// Get grievance id
$id = mysqli_real_escape_string($connection, $_GET['id']);
// If user tries to access grievances using grievance id in which their email id is not mentioned, redirect to track.php page
if ($_SESSION['email'] === $_SESSION['admin']) {
    $sql = "SELECT * 
            FROM `grievance_details`, `grievance_to` 
            WHERE grievance_details.id = grievance_to.grievance_id 
            AND grievance_details.id = ?";
    $result = $connection->prepare($sql);
    $result->bind_param('i', $id);
} else {
    $sql = "SELECT * 
            FROM `grievance_details`, `grievance_to` 
            WHERE grievance_details.id = grievance_to.grievance_id 
            AND grievance_details.id = ? 
            AND (grievance_details.email = ? 
                  OR grievance_to.email = ?);";
    $result = $connection->prepare($sql);
    $result->bind_param('iss', $id, $_SESSION['email'], $_SESSION['email']);
}

$result->execute();
$res = $result->get_result();

// If user tries to access grievances using grievance id in which their email id is not mentioned, redirect to track.php page
if ($res->num_rows <= 0) {
    header('Location: track.php');
    exit;
} else {
    $row = $res->fetch_assoc();
    $_SESSION['status'] = strtolower($row['status']);
}
?>


<div class="container">
    <div class="row">
        <div class="col s12 m3 l3">
            <div class="card z-depth-5">
                <div class="card-content">
                    <span class="card-title grey-text text-darken-4">Date Registered</span>
                    <p>
                        <?php
                        echo date('F j, Y', strtotime($row['date_time']));
                        ?>
                    </p>
                </div>
            </div>

            <div class="card z-depth-5">
                <div class="card-content">
                    <span class="card-title grey-text text-darken-4">Status</span>
                    <?php
                    if (isset($_SESSION['login_type']) && $_SESSION['login_type'] === "faculty") {
                        $reg = "";
                        $solved = "";
                        $cannotSolve = "";
                        if (strtolower($row['status']) === "registered") {
                            $reg = "selected";
                        } else if (strtolower($row['status']) === "solved") {
                            $solved = "selected";
                        } else if (strtolower($row['status']) === "cannot solve") {
                            $cannotSolve = "selected";
                        }
                        echo "
                                    <select id='status'>
                                      <option value=\"Registered\" " . $reg . ">Registered</option>
                                      <option value=\"Solved\" " . $solved . ">Mark As Solved</option>
                                      <option value=\"Cannot Solve\" " . $cannotSolve . ">Mark As Cannot Solve</option>
                                    </select>
                                ";
                    } else if (isset($_SESSION['login_type']) && $_SESSION['login_type'] === "student") {
                        echo "<p>" . ucfirst($row['status']) . "</p>";
                    }
                    ?>
                </div>
            </div>

            <div class="card z-depth-5">
                <div class="card-content">
                    <span class="card-title grey-text text-darken-4">Grievance Type</span>
                    <p><?php echo ucfirst($row['type']); ?></p>
                </div>
            </div>
        </div>

        <div class="col s12 m9 l9">
            <div class="card z-depth-5">
                <div class="card-content">
                    <span class="card-title">Grievance Description</span>
                    <p class="justify">
                        <?php echo $row['description']; ?>
                    </p>
                </div>
            </div>
        </div>

        <?php
        // Fetch all previous responses.
        $sql = "SELECT *
                    FROM `grievance_response`
                    WHERE grievance_id = ? ORDER BY date_time;";
        $result = $connection->prepare($sql);
        $result->bind_param('i', $id);
        $result->execute();
        $res = $result->get_result();

        $html = "";
        while ($row = $res->fetch_assoc()) {
            $from = "";
            // Card Title.
            if ($_SESSION['admin'] === $_SESSION['email']) {
                // Admin is logged in, show the names of everyone involved.
                $from = $row['response_from'];
            } else if ($row['response_from'] === $_SESSION['name']) {
                // Show their name in the response.
                $from = $row['response_from'];
            } else {
                // If it's not admin, don't display the name of other person.
                $from = $_SESSION['login_type'] == "faculty" ? "Student" : "Faculty";
            }

            // Response card.
            $html .= "<div class=\"col s12 m9 l9 right\">
            <div class=\"card z-depth-5\">
                <div class=\"card-content\">
                    <span class=\"card-title\">" . $from . "</span>
                    <p>Date: " . date('F j, Y', strtotime($row['date_time'])) . "</p>
                    <p>Time: " . date('h:i:s A', strtotime($row['date_time'])) . "</p>
                    <p class='justify'>
                      <br>  " . stripcslashes(str_replace('\n', '<br />', $row['response'])) . "
                    </p>
                    </div>
                </div>
            </div>";
        }

        echo $html;
        ?>

        <div class="col s12 m9 l9 right" id="addResponseTextArea">
            <div class="card z-depth-5">
                <div class="card-content">
                    <span class="card-title">Add Response</span>
                    <div class="input-field">
                        <textarea id="addResponse" placeholder="Add Response" class="materialize-textarea"></textarea>
                        <span class="helper-text red-text text-darken-2" id="addResponseError"></span>
                    </div>

                    <div class="row">
                        <button class="btn waves-effect waves-light brown lighten-1 right" id="submit">Submit
                            <i class="material-icons right">send</i>
                        </button>
                    </div>

                </div>
            </div>
        </div>
    </div>
</div>

<?php include 'templates/modals.php'; ?>

<?php include 'templates/footer.php'; ?>

<!-- jQuery cdn -->
<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>
<!-- Compiled and minified JavaScript -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/materialize/1.0.0-rc.2/js/materialize.min.js"></script>

<script>
    $(document).ready(function () {
        $('.sidenav').sidenav();
        var wait = $("#wait").modal({
            opacity: 0.75,
            preventScrolling: true,
            dismissible: false,
        });

        var failed = $("#failedToInsert").modal({
            opacity: 0.75,
            preventScrolling: true,
            dismissible: false,
        });

        <?php
        if (isset($_SESSION['login_type']) && $_SESSION['login_type'] === "faculty") {
            echo "$('select').formSelect();";
            echo "var updated = $(\"#updated\").modal({
                    opacity: 0.75,
                    preventScrolling: true,
                    dismissible: false,
                    onCloseEnd: function () {
                        window.location.href = \"grievanceDetails.php?id=$id\";
                    }
                });

                $('#status').on('change', function() {
                    var status = this.value;
                    $.ajax({
                        beforeSend: function () {
                            wait.modal('open');
                        },
                        url: \"io/changeStatus.php\",
                        data: JSON.stringify({\"grievanceID\": " . $id . ", \"status\": status}),
                        type: 'POST',
                        success: function (data, status) {
                            if (status === \"success\") {
                                wait.modal('close');
                                if (JSON.parse(data).status === \"success\") {
                                    // Data entered to database successfully
                                    updated.modal('open');
                                } else {
                                    // Failed to insert data.
                                    failed.modal('open');
                                }
                            }
                        }
                    });
                });";
        }

        // Show toast msg if insertion is successful.
        if (isset($_SESSION['response_inserted']) && $_SESSION['response_inserted'] === "success") {
            // Show toast message.
            echo 'M.toast({html: \'Response Recorded!\', classes: \'rounded\'})';
            // Prevents displaying toast again and again.
            $_SESSION['response_inserted'] = "";
        }
        ?>

        // Default values.
        var grievanceResponse = null;

        // Clear error messages when clicked on any input elements.
        $(":input").click(function () {
            $('#addResponseError').html("");
        });

        <?php
        // Disable input if the grievance is marked as solved or cannot solve.
        if (isset($_SESSION['status']) && ($_SESSION['status'] === "solved" || $_SESSION['status'] === "cannot solve")) {
            echo "$('#addResponseTextArea').hide();";
        }
        ?>

        $('#submit').click(function () {
            grievanceResponse = $('#addResponse').val();

            if (grievanceResponse === null || grievanceResponse.length <= 0) {
                $('#addResponseError').html("Please write your response");
            } else {
                var response = $('#addResponse').val();

                $.ajax({
                    beforeSend: function () {
                        wait.modal('open');
                    },
                    url: "io/addResponse.php",
                    data: JSON.stringify({"grievanceID": <?php echo $id; ?>, "response": response}),
                    type: 'POST',
                    success: function (data, status) {
                        if (status === "success") {
                            if (JSON.parse(data).status === "success") {
                                // Data entered to database successfully
                                window.location.href = "grievanceDetails.php?id=<?php echo $id; ?>";
                            } else {
                                // Failed to insert data.
                                wait.modal('close');
                                failed.modal('open');
                            }
                        }
                    }
                });
            }
        });
    });
</script>

</body>
</html>